#!/usr/bin/env python

"""
package-components.py

A tool for creating new package description files, and for building packages
from the XML descriptions in those files.

Copyright (C) 2005 David Boddie <david@boddie.org.uk>

This software is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

This software is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public
License along with this library; see the file COPYING
If not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""

import glob, os, sys, urlparse
from xml.dom.minidom import parse, Document

class package_error(Exception):

    pass

def mkdir(directory, created):

    if os.path.isdir(directory):
    
        return
    
    elif os.path.exists(directory):
    
        print "Could not create the support directory: %s" % path
        raise package_error
    
    try:
    
        os.mkdir(directory)
        created.append(directory)
    
    except OSError:
    
        print "Could not create the support directory: %s" % path
        raise package_error

def cp(source_file, destination_dir):

    try:
    
        os.system("cp %s %s" % (source_file, destination_dir))
    
    except OSError:
    
        print "Could not copy %s into %s" % (source_file, destination_dir)
        raise package_error


def construct_package(element, package_dir, created):

    # Try to create the directory specified.
    mkdir(package_dir, created)
    
    # Examine each item in the distribution structure.
    
    for node in element.childNodes:
    
        if node.nodeType != node.ELEMENT_NODE:
        
            continue
        
        element = node
        
        url = element.getAttribute("url")
        path = urlparse.urlparse(url)[2]
        
        # The object may be packaged using a different name.
        pkg_name = element.getAttribute("name")
        
        if element.nodeName == u"file":
        
            # Include this item in the package.
            mimetype = element.getAttribute("mimetype")
            
            # Rename the file as they are copied.
            cp(path, os.path.join(package_dir, pkg_name))
        
        elif element.nodeName == u"directory":
        
            # This is a directory.
            construct_package(
                element, os.path.join(package_dir, pkg_name), created
                )
        
        else:
        
            sys.stderr.write('Unknown item: <%s name="%s" url="%s"...>\n' % \
                repr(element.nodeName, pkg_name, url)
                )

def create_new_package(package_file, name = None):

    package_file = os.path.abspath(package_file)

    if os.path.exists(package_file):
    
        sys.stderr.write(
            "The specified package already exists: %s\n" % package_file
            )
        sys.exit(1)
    
    try:
    
        f = open(package_file, "w")
        document = Document()
        package = document.createElement(u"package")
        document.appendChild(package)
        
        if name is not None:
        
            package.setAttribute(u"name", unicode(name))
        
        f.write(document.toxml())
        f.close()
    
    except IOError:
    
        sys.stderr.write("Failed to create the package file: %s\n" % package_file)
        sys.exit(1)

def build_package(package_file, dir_name = None):

    package_file = os.path.abspath(package_file)

    # Parse the package file.
    document = parse(package_file)
    
    package = document.documentElement
    
    if dir_name is None and package.hasAttribute("name"):
    
        dir_name = package.getAttribute("name")
    
    if dir_name is None:
    
        sys.stderr.write(
            "This package file does not contain a title. "
            "Please specify a build directory.\n"
            )
        sys.exit(1)
    
    package_dir = os.path.abspath(dir_name)
    
    if os.path.exists(package_dir):
    
        sys.stderr.write(
            "The specified package directory already exists: %s\n" % package_dir
            )
        sys.exit(1)
    
    # Maintain a list of directories created.
    created = []
    
    try:
    
        construct_package(package, package_dir, created)
    
    except package_error:
    
        # Remove the built directories.
        for d in created:
        
            os.remove(d)


if __name__ == "__main__":

    
    syntax = (
        "  %(app)s --new <package file> [--title <name>]\n"
        "  %(app)s --build <package file> [<build directory>]\n"
        )
    
    args = sys.argv[1:]
    
    try:
    
        if "--new" in args:
        
            at = args.index("--new")
            command = "new"
            package_file = args[at+1]
            
            if "--title" in sys.argv[at+2:]:
            
                at = args.index("--title")
                name = args[at+1]
                create_new_package(package_file, name = name)
            
            else:
            
                create_new_package(package_file)
        
        elif "--build" in args:
        
            at = args.index("--build")
            command = "build"
            package_file = args[at+1]
            
            if len(args) == at+3:
            
                name = args[at+2]
                build_package(package_file, dir_name = name)
            
            else:
            
                build_package(package_file)
        
        else:
        
            raise IndexError
    
    except IndexError:
    
        sys.stderr.write("Usage:\n\n%s\n" % syntax % {"app": sys.argv[0]})
        sys.exit(1)
    
    # Exit
    sys.exit()
